==> chat-engine-ui-0.0.2.tgz: package/lib/components/MessageBubble.js <==
import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';
import styled from 'styled-components';

const bubblePerspective = ({ fromFriend, top, bottom }) => {
  if (fromFriend) {
    if (top) {
      return '15px 15px 15px 5px';
    } if (bottom) {
      return '5px 15px 15px 15px';
    }
    return '5px 15px 15px 5px';
  }
  if (top) {
    return '15px 15px 5px 15px';
  } if (bottom) {
    return '15px 5px 15px 15px';
  }
  return '15px 5px 5px 15px';
};

const BubbleText = styled.p`
    display: inline;
    color: ${props => props.color || '#222f3e'};
    font-family: ${props => props.font || 'helvetica'};
`;
const BubbleContainer = styled.div`
    max-width: 40%;
    word-wrap: break-word;
    clear: both;
    display: inline;
    margin: 1px;
    float: ${props => (props.fromFriend ? 'left' : 'right')};
    padding: 0.5em;
    background: ${props => props.background || '#dfe4ea'};
    border-radius: ${props => bubblePerspective(props)};
`;

export default class MessageBubble extends PureComponent {
  render() {
    const {
      text, background, color, fromFriend, top, bottom,
    } = this.props;
    return (
      <BubbleContainer
        background={background}
        fromFriend={fromFriend}
        bottom={bottom}
        top={top}
      >
        <BubbleText
          color={color}
        >
          { text }
        </BubbleText>
      </BubbleContainer>
    );
  }
}

MessageBubble.propTypes = {
  text: PropTypes.string.isRequired,
  background: PropTypes.string,
  color: PropTypes.string,
  font: PropTypes.string,
  fromFriend: PropTypes.bool,
  top: PropTypes.bool,
  bottom: PropTypes.bool,
  style: PropTypes.string
};

==> chat-engine-ui-0.0.7.tgz: package/lib/components/MessageBubble.js <==
import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';
import styled from 'styled-components';

const bubblePerspective = ({ fromFriend, top, bottom }) => {
  if (fromFriend) {
    if (top) {
      return '15px 15px 15px 5px';
    } if (bottom) {
      return '5px 15px 15px 15px';
    }
    return '5px 15px 15px 5px';
  }
  if (top) {
    return '15px 15px 5px 15px';
  } if (bottom) {
    return '15px 5px 15px 15px';
  }
  return '15px 5px 5px 15px';
};

const BubbleText = styled.p`
    display: inline;
    color: ${props => props.color || '#222f3e'};
    font-family: ${props => props.font || "'Open Sans', sans-serif"};
`;
const BubbleContainer = styled.div`
    max-width: 65%;
    word-wrap: break-word;
    clear: both;
    display: inline;
    margin: 1px;
    float: ${props => (props.fromFriend ? 'left' : 'right')};
    padding: 0.5em;
    background: ${props => props.background || '#dfe4ea'};
    border-radius: ${props => bubblePerspective(props)};
`;

export default class MessageBubble extends PureComponent {
  render() {
    const {
      text, background, color, fromFriend, top, bottom,
    } = this.props;
    return (
      <BubbleContainer
        background={background}
        fromFriend={fromFriend}
        bottom={bottom}
        top={top}
      >
        <BubbleText
          color={color}
        >
          { text }
        </BubbleText>
      </BubbleContainer>
    );
  }
}

MessageBubble.propTypes = {
  text: PropTypes.string.isRequired,
  background: PropTypes.string,
  color: PropTypes.string,
  font: PropTypes.string,
  fromFriend: PropTypes.bool,
  top: PropTypes.bool,
  bottom: PropTypes.bool,
  style: PropTypes.string
};
